@@ -2,7 +2,7 @@ package FFI::Build;
 
 use strict;
 use warnings;
-use 5.008001;
+use 5.008004;
 use FFI::Build::File::Library;
 use Carp ();
 use File::Glob ();
@@ -12,7 +12,16 @@ use Capture::Tiny ();
 use File::Path ();
 
 # ABSTRACT: Build shared libraries for use with FFI
-our $VERSION = '1.27_01'; # TRIAL VERSION
+our $VERSION = '1.35_01'; # TRIAL VERSION
+
+# Platypus-Man,
+# Platypus-Man,
+# Friendly Neighborhood Platypus-Man
+# Is He Strong?
+# Listen Bud
+# He's got Proportional Strength of a Platypus
+# Hey Man!
+# There Goes The Platypus-Man
 
 
 sub _native_name
@@ -302,11 +311,11 @@ FFI::Build - Build shared libraries for use with FFI
 
 =head1 VERSION
 
-version 1.27_01
+version 1.35_01
 
 =head1 SYNOPSIS
 
- use FFI::Platypus;
+ use FFI::Platypus 1.00;
  use FFI::Build;
  
  my $build = FFI::Build->new(
@@ -547,9 +556,11 @@ Meredith (merrilymeredith, MHOWARD)
 
 Diab Jerius (DJERIUS)
 
+Eric Brine (IKEGAMI)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
+This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
