@@ -2,7 +2,7 @@ package FFI::Build::Platform;
 
 use strict;
 use warnings;
-use 5.008001;
+use 5.008004;
 use Carp ();
 use Text::ParseWords ();
 use FFI::Temp;
@@ -11,7 +11,7 @@ use File::Spec;
 use FFI::Platypus::ShareConfig;
 
 # ABSTRACT: Platform specific configuration.
-our $VERSION = '1.27_01'; # TRIAL VERSION
+our $VERSION = '1.35_01'; # TRIAL VERSION
 
 
 sub new
@@ -147,7 +147,7 @@ sub cxx
   }
   elsif($self->osname eq 'MSWin32' && $self->{config}->{ccname} eq 'cl')
   {
-    # TODO: see https://github.com/Perl5-FFI/FFI-Platypus/issues/203
+    # TODO: see https://github.com/PerlFFI/FFI-Platypus/issues/203
     #return \@cc;
   }
 
@@ -194,7 +194,7 @@ sub shellwords
 {
   my $self = _self(shift);
 
-  my $win = !!$self->osname eq 'MSWin32';
+  my $win = !!($self->osname eq 'MSWin32');
 
   grep { defined $_ } map {
     ref $_
@@ -421,7 +421,7 @@ FFI::Build::Platform - Platform specific configuration.
 
 =head1 VERSION
 
-version 1.27_01
+version 1.35_01
 
 =head1 SYNOPSIS
 
@@ -613,9 +613,11 @@ Meredith (merrilymeredith, MHOWARD)
 
 Diab Jerius (DJERIUS)
 
+Eric Brine (IKEGAMI)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
+This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
