@@ -2,20 +2,21 @@ package FFI::Platypus;
 
 use strict;
 use warnings;
-use 5.008001;
+use 5.008004;
 use Carp qw( croak );
 use FFI::Platypus::Function;
 use FFI::Platypus::Type;
 
 # ABSTRACT: Write Perl bindings to non-Perl libraries with FFI. No XS required.
-our $VERSION = '1.27_01'; # TRIAL VERSION
+our $VERSION = '1.35_01'; # TRIAL VERSION
 
-# Platypus Man,
-# Platypus Man,
-# Does Everything The Platypus Can
-# ...
-# Watch Out!
-# Here Comes The Platypus Man
+# Platypus-Man,
+# Platypus-Man,
+# Does Whatever A Platypus Can
+# Is Mildly Venomous
+# Hangs Out In Rivers By Caves
+# Look Out!
+# Here Comes The Platypus-Man
 
 # From the original FFI::Platypus prototype:
 #  Kinda like gluing a duckbill to an adorable mammal
@@ -583,11 +584,11 @@ FFI::Platypus - Write Perl bindings to non-Perl libraries with FFI. No XS requir
 
 =head1 VERSION
 
-version 1.27_01
+version 1.35_01
 
 =head1 SYNOPSIS
 
- use FFI::Platypus;
+ use FFI::Platypus 1.00;
  
  # for all new code you should use api => 1
  my $ffi = FFI::Platypus->new( api => 1 );
@@ -954,7 +955,7 @@ L<attach|/attach> method.
 In addition to looking up a function by name you can provide the address
 of the symbol yourself:
 
- my $address = $ffi->find_symbol('my_functon');
+ my $address = $ffi->find_symbol('my_function');
  my $function = $ffi->function($address => ...);
 
 Under the covers, L<function|/function> uses L<find_symbol|/find_symbol>
@@ -1029,8 +1030,8 @@ method.
 
 Examples:
 
- $ffi->attach('my_functon_name', ['int', 'string'] => 'string');
- $ffi->attach(['my_c_functon_name' => 'my_perl_function_name'], ['int', 'string'] => 'string');
+ $ffi->attach('my_function_name', ['int', 'string'] => 'string');
+ $ffi->attach(['my_c_function_name' => 'my_perl_function_name'], ['int', 'string'] => 'string');
  my $string1 = my_function_name($int);
  my $string2 = my_perl_function_name($int);
 
@@ -1527,8 +1528,13 @@ use C<undef> as the library to find them.
  
  puts(strerror(2));
 
-B<Discussion>: Strings are not a native type to C<libffi> but the are
-handled seamlessly by Platypus.
+B<Discussion>: ASCII and UTF-8 Strings are not a native type to C<libffi>
+but the are handled seamlessly by Platypus.  If you need to talk to an
+API that uses so called "wide" strings (APIs which use C<const wchar_t*>
+or C<wchar_t*>), then you will want to use the wide string type plugin
+L<FFI::Platypus::Type::WideString>.  APIs which use other arbitrary
+encodings can be accessed by converting your Perl strings manually with
+the L<Encode> module.
 
 =head2 Attach function from pointer
 
@@ -1914,6 +1920,35 @@ will come in after that.  This allows you to modify / convert the
 arguments to conform to the C API.  What ever value you return from the
 wrapper function will be returned back to the original caller.
 
+=head2 The Win32 API
+
+ use utf8;
+ use FFI::Platypus;
+ 
+ my $ffi = FFI::Platypus->new(
+   api  => 1,
+   lib  => [undef],
+ );
+ 
+ # see FFI::Platypus::Lang::Win32
+ $ffi->lang('Win32');
+ 
+ # Send a Unicode string to the Windows API MessageBoxW function.
+ use constant MB_OK                   => 0x00000000;
+ use constant MB_DEFAULT_DESKTOP_ONLY => 0x00020000;
+ $ffi->attach( [MessageBoxW => 'MessageBox'] => [ 'HWND', 'LPCWSTR', 'LPCWSTR', 'UINT'] => 'int' );
+ MessageBox(undef, "I ❤️ Platypus", "Confession", MB_OK|MB_DEFAULT_DESKTOP_ONLY);
+
+B<Discussion>: The API used by Microsoft Windows present some unique
+challenges.  On 32 bit systems a different ABI is used than what is
+used by the standard C library.  It also provides a rats nest of
+type aliases.  Finally if you want to talk Unicode to any of the
+Windows API you will need to use C<UTF-16LE> instead of C<utf-8>
+which is native to Perl.  (The Win32 API refers to these as
+C<LPWSTR> and C<LPCWSTR> types).  As much as possible the Win32
+"language" plugin attempts to handle this transparently.  For more
+details see L<FFI::Platypus::Lang::Win32>.
+
 =head2 bundle your own code
 
 C<ffi/foo.c>:
@@ -2037,6 +2072,9 @@ is identical to the process of defining macro constants in Perl.
 
 For more details on enumerated types see L<FFI::Platypus::Type/"Enum types">.
 
+There is also a type plugin (L<FFI::Platypus::Type::Enum>) that can be helpful
+in writing interfaces that use enums.
+
 =head2 Memory leaks
 
 There are a couple places where memory is allocated, but never deallocated that may
@@ -2085,7 +2123,7 @@ That means all the way back to 5.8.1.  Unfortunately, 5.10.0 seems to have a pro
 that is difficult to diagnose.  Patches to fix are welcome, if you want to help
 out on this, please see:
 
-L<https://github.com/Perl5-FFI/FFI-Platypus/issues/68>
+L<https://github.com/PerlFFI/FFI-Platypus/issues/68>
 
 Since this is an older buggy version of Perl it is recommended that you instead
 upgrade to 5.10.1 or later.
@@ -2139,14 +2177,14 @@ If something does not work the way you think it should, or if you have a
 feature request, please open an issue on this project's GitHub Issue
 tracker:
 
-L<https://github.com/perl5-FFI/FFI-Platypus/issues>
+L<https://github.com/perlFFI/FFI-Platypus/issues>
 
 =head1 CONTRIBUTING
 
 If you have implemented a new feature or fixed a bug then you may make a
 pull request on this project's GitHub repository:
 
-L<https://github.com/Perl5-FFI/FFI-Platypus/pulls>
+L<https://github.com/PerlFFI/FFI-Platypus/pulls>
 
 This project is developed using L<Dist::Zilla>.  The project's git
 repository also comes with the C<Makefile.PL> file necessary
@@ -2270,7 +2308,7 @@ making significant changes to the Platypus Core.  For that I use
 
 =over 4
 
-=item L<https://github.com/Perl5-FFI/FFI-Performance>
+=item L<https://github.com/PerlFFI/FFI-Performance>
 
 =back
 
@@ -2355,6 +2393,16 @@ language
 
 Documentation and tools for using Platypus with the Assembly
 
+=item L<FFI::Platypus::Lang::Win32>
+
+Documentation and tools for using Platypus with the Win32 API.
+
+=item L<Wasm> and L<Wasm::Wasmtime>
+
+Modules for writing WebAssembly bindings in Perl.  This allows you to call
+functions written in any language supported by WebAssembly.  These modules
+are also implemented using Platypus.
+
 =item L<Convert::Binary::C>
 
 A great interface for decoding C data structures, including C<struct>s,
@@ -2455,9 +2503,11 @@ Meredith (merrilymeredith, MHOWARD)
 
 Diab Jerius (DJERIUS)
 
+Eric Brine (IKEGAMI)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
+This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
