@@ -2,6 +2,7 @@ package FFI::Platypus::Buffer;
 
 use strict;
 use warnings;
+use 5.008004;
 use FFI::Platypus;
 use base qw( Exporter );
 
@@ -9,7 +10,7 @@ our @EXPORT = qw( scalar_to_buffer buffer_to_scalar );
 our @EXPORT_OK = qw ( scalar_to_pointer grow set_used_length window );
 
 # ABSTRACT: Convert scalars to C buffers
-our $VERSION = '1.27_01'; # TRIAL VERSION
+our $VERSION = '1.35_01'; # TRIAL VERSION
 
 
 use constant _incantation =>
@@ -49,7 +50,7 @@ FFI::Platypus::Buffer - Convert scalars to C buffers
 
 =head1 VERSION
 
-version 1.27_01
+version 1.35_01
 
 =head1 SYNOPSIS
 
@@ -233,17 +234,21 @@ Not exported by default, but may be exported on request.
 
 =head2 window
 
+ window $scalar, $pointer;
  window $scalar, $pointer, $size;
  window $scalar, $pointer, $size, $utf8;
 
 This makes the scalar a read-only window into the arbitrary region of
 memory defined by C<$pointer>, pointing to the start of the region
-and C<$size>, the size of the region.  This can be useful if you have
-a C function that returns a buffer pair (pointer, size), and want to
-access it from Perl without having to copy the data.  This can also
-be useful when interfacing with programming languages that store
-strings as a address/length pair instead of a pointer to
-null-terminated sequence of bytes.
+and C<$size>, the size of the region.  If C<$size> is omitted then
+it will assume a C style string and use the C C<strlen> function to
+determine the size (the terminating C<'\0'> will not be included).
+
+This can be useful if you have a C function that returns a buffer
+pair (pointer, size), and want to access it from Perl without having
+to copy the data.  This can also be useful when interfacing with
+programming languages that store strings as a address/length pair
+instead of a pointer to null-terminated sequence of bytes.
 
 You can specify C<$utf8> to set the UTF-8 flag on the scalar.  Note
 that the behavior of setting the UTF-8 flag on a buffer that does
@@ -341,9 +346,11 @@ Meredith (merrilymeredith, MHOWARD)
 
 Diab Jerius (DJERIUS)
 
+Eric Brine (IKEGAMI)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
+This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
