@@ -2,10 +2,10 @@ package FFI::Platypus::Lang;
 
 use strict;
 use warnings;
-use 5.008001;
+use 5.008004;
 
 # ABSTRACT: Language specific customizations
-our $VERSION = '1.27_01'; # TRIAL VERSION
+our $VERSION = '1.35_01'; # TRIAL VERSION
 
 
 
@@ -23,7 +23,7 @@ FFI::Platypus::Lang - Language specific customizations
 
 =head1 VERSION
 
-version 1.27_01
+version 1.35_01
 
 =head1 SYNOPSIS
 
@@ -43,8 +43,42 @@ This package itself doesn't do anything, it serves only as documentation.
 
 =item L<FFI::Platypus>
 
+Platypus itself.
+
+=item L<FFI::Platypus::Lang::ASM>
+
+This language plugin provides no type aliases, and is intended
+for use with assembly language or for when no other language
+plugin is appropriate.
+
 =item L<FFI::Platypus::Lang::C>
 
+Language plugin for the C programming language.
+
+=item L<FFI::Platypus::Lang::Fortran>
+
+Non-core language plugin for the Fortran programming language.
+
+=item L<FFI::Platypus::Lang::CPP>
+
+Non-core language plugin for the C++ programming language.
+
+=item L<FFI::Platypus::Lang::Go>
+
+Non-core language plugin for the Go programming language.
+
+=item L<FFI::Platypus::Lang::Pascal>
+
+Non-core language plugin for the Pascal programming language.
+
+=item L<FFI::Platypus::Lang::Rust>
+
+Non-core language plugin for the Rust programming language.
+
+=item L<FFI::Platypus::Lang::Win32>
+
+Language plugin for use with the Win32 API.
+
 =back
 
 =head1 AUTHOR
@@ -83,9 +117,11 @@ Meredith (merrilymeredith, MHOWARD)
 
 Diab Jerius (DJERIUS)
 
+Eric Brine (IKEGAMI)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
+This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
