@@ -2,9 +2,10 @@ package FFI::Platypus::Record::Meta;
 
 use strict;
 use warnings;
+use 5.008004;
 
 # ABSTRACT: FFI support for structured records data
-our $VERSION = '1.27_01'; # TRIAL VERSION
+our $VERSION = '1.35_01'; # TRIAL VERSION
 
 
 {
@@ -62,7 +63,7 @@ our $VERSION = '1.27_01'; # TRIAL VERSION
 
   $ffi->attach( ffi_type         => ['meta_t'] => 'ffi_type'   );
   $ffi->attach( size             => ['meta_t'] => 'size_t'     );
-  $ffi->attach( alignment        => ['meta_t'] => 'uint'       );
+  $ffi->attach( alignment        => ['meta_t'] => 'ushort'     );
   $ffi->attach( element_pointers => ['meta_t'] => 'ffi_type[]' );
 
   $ffi->attach( DESTROY          => ['meta_t'] => 'void'       );
@@ -82,7 +83,7 @@ FFI::Platypus::Record::Meta - FFI support for structured records data
 
 =head1 VERSION
 
-version 1.27_01
+version 1.35_01
 
 =head1 DESCRIPTION
 
@@ -125,9 +126,11 @@ Meredith (merrilymeredith, MHOWARD)
 
 Diab Jerius (DJERIUS)
 
+Eric Brine (IKEGAMI)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
+This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
