@@ -2,10 +2,11 @@ package FFI::Platypus::Record::TieArray;
 
 use strict;
 use warnings;
+use 5.008004;
 use Carp qw( croak );
 
 # ABSTRACT: Tied array interface for record array members
-our $VERSION = '1.27_01'; # TRIAL VERSION
+our $VERSION = '1.35_01'; # TRIAL VERSION
 
 
 sub TIEARRAY
@@ -62,7 +63,7 @@ FFI::Platypus::Record::TieArray - Tied array interface for record array members
 
 =head1 VERSION
 
-version 1.27_01
+version 1.35_01
 
 =head1 SYNOPSIS
 
@@ -153,9 +154,11 @@ Meredith (merrilymeredith, MHOWARD)
 
 Diab Jerius (DJERIUS)
 
+Eric Brine (IKEGAMI)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
+This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
