@@ -2,11 +2,12 @@ package FFI::Platypus::Type::StringPointer;
 
 use strict;
 use warnings;
+use 5.008004;
 use FFI::Platypus;
 use Scalar::Util qw( readonly );
 
 # ABSTRACT: Convert a pointer to a string and back
-our $VERSION = '1.27_01'; # TRIAL VERSION
+our $VERSION = '1.35_01'; # TRIAL VERSION
 
 
 use constant _incantation =>
@@ -75,7 +76,7 @@ FFI::Platypus::Type::StringPointer - Convert a pointer to a string and back
 
 =head1 VERSION
 
-version 1.27_01
+version 1.35_01
 
 =head1 SYNOPSIS
 
@@ -169,9 +170,11 @@ Meredith (merrilymeredith, MHOWARD)
 
 Diab Jerius (DJERIUS)
 
+Eric Brine (IKEGAMI)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
+This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
