@@ -2,11 +2,12 @@ package FFI::Platypus::TypeParser;
 
 use strict;
 use warnings;
+use 5.008004;
 use List::Util 1.45 qw( uniqstr );
 use Carp qw( croak );
 
 # ABSTRACT: FFI Type Parser
-our $VERSION = '1.27_01'; # TRIAL VERSION
+our $VERSION = '1.35_01'; # TRIAL VERSION
 
 
 # The TypeParser and Type classes are used internally ONLY and
@@ -111,7 +112,7 @@ FFI::Platypus::TypeParser - FFI Type Parser
 
 =head1 VERSION
 
-version 1.27_01
+version 1.35_01
 
 =head1 DESCRIPTION
 
@@ -154,9 +155,11 @@ Meredith (merrilymeredith, MHOWARD)
 
 Diab Jerius (DJERIUS)
 
+Eric Brine (IKEGAMI)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
+This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
